#
# spec file for package notmuch
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           notmuch
Version:        0.26
Release:        lp150.1.1
Summary:        The mail indexer
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Email/Utilities
Url:            http://notmuchmail.org
Source0:        http://notmuchmail.org/releases/%{name}-%{version}.tar.gz
Source1:        http://notmuchmail.org/releases/%{name}-%{version}.tar.gz.sha256
Source2:        http://notmuchmail.org/releases/%{name}-%{version}.tar.gz.sha256.asc
Source3:        notmuch.keyring

%{bcond_without python}
%{bcond_without python3}
%{bcond_without emacs}

#FIXME: at they are not enabled
%{bcond_with ruby}
%{bcond_with go}

%define libversion 5

BuildRequires:  libxapian-devel
BuildRequires:  pkg-config
%if 0%{?suse_version} == 1315
BuildRequires:  pkgconfig(gmime-2.6)
%else
BuildRequires:  pkgconfig(gmime-3.0)
%endif
BuildRequires:  python3-Sphinx
BuildRequires:  pkgconfig(talloc)

%if %{with emacs}
BuildRequires:  emacs-el
BuildRequires:  emacs-nox
%endif
%if %{with python}
BuildRequires:  python-devel
%endif
%if %{with python3}
BuildRequires:  python3-devel
%endif
%if %{with ruby}
BuildRequires:  ruby-devel
%endif
%if %{with go}
BuildRequires:  go
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Because dealing with your mail can be so much better.

"Not much mail" is what Notmuch thinks about your email collection. Even if
you receive 12000 messages per month or have on the order of millions of
messages that you've been saving for decades. Regardless, Notmuch will be
able to quickly search all of it. It's just plain not much mail.

"Not much mail" is also what you should have in your inbox at any time.
Notmuch gives you what you need, (tags and fast search), so that you can
keep your inbox tamed and focus on what really matters in your life, (which
is surely not email).

Notmuch is an answer to Sup. Sup is a very good email program written by
William Morgan (and others) and is the direct inspiration for Notmuch.
Notmuch began as an effort to rewrite performance-critical pieces of Sup in
C rather than ruby. From there, it grew into a separate project. One
significant contribution Notmuch makes compared to Sup is the separation of
the indexer/searcher from the user interface. (Notmuch provides a library
interface so that its indexing/searching/tagging features can be integrated
into any email program.)

Notmuch is not much of an email program. It doesn't receive messages (no
POP or IMAP support). It doesn't send messages (no mail composer, no
network code at all). And for what it does do (email search) that work is
provided by an external library, Xapian. So if Notmuch provides no user
interface and Xapian does all the heavy lifting, then what's left here? Not
much.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       libnotmuch%{libversion} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package -n libnotmuch%{libversion}
Summary:        A shared library for %{name}
Group:          Productivity/Networking/Email/Utilities

%description -n libnotmuch%{libversion}
The libnotmuch3 package contains shared libraries for %{name}.

%if %{with python}
%package -n python-%{name}
Summary:        Python bindings for %{name}
#py_requires is useless as it was not designed for sub-packages
#BR: python-devel is on the top of spec file
Group:          Development/Libraries/Python
Requires:       python = %{py_ver}
Recommends:     python-%{name}-doc = %{version}

%description -n python-%{name}
Python interface (bindings) for %{name}

%package -n python-%{name}-doc
Summary:        Documentation of Python bindings for %{name}
Group:          Documentation/HTML

%description -n python-%{name}-doc
Documentation of Python interface (bindings) for %{name}
%endif

%if %{with python3}
%package -n python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Libraries/Python
Requires:       python = %{py3_ver}
%if %{with python}
#documentation is built only when python2 is installed
#this shall be fixed once python2 disappear from openSUSE
Recommends:     python-%{name}-doc = %{version}
%endif

%description -n python3-%{name}
Python3 interface (bindings) for %{name}
%endif

%if %{with emacs}
%package emacs
Summary:        Emacs lisp email client based on %{name}
Group:          Productivity/Networking/Email/Utilities
Requires:       %{name} = %{version}-%{release}
Requires:       emacs
Requires:       emacs-el

%description emacs
%{name}-based email client written in emacs lisp
%endif

%prep
%setup -q

%build
#hand-made configure script
#zsh completion is a part of zsh itself
export CFLAGS="%{optflags}"
./configure \
%if %{without emacs}
  --without-emacs \
%endif
  --without-zsh-completion \
  --prefix=%{_prefix} \
  --libdir=%{_libdir} \
  --includedir=%{_includedir} \
  --mandir=%{_mandir} \
  --sysconfdir=%{_sysconfdir}

#XXX: failed to build with smp_flags
#make %{?_smp_mflags}
make

#TODO: bindings - go, ruby
pushd bindings

%if %{with python3}
cp -r python python3
pushd python3
python3 setup.py build
popd
%endif

%if %{with python}
pushd python
python2 setup.py build
pushd docs
make dirhtml
rm -f build/dirhtml/.buildinfo
popd
popd
%endif

popd

%install
%make_install

%if %{with python3}
pushd bindings/python3
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
popd
%endif

%if %{with python}
pushd bindings/python
python2 setup.py install --prefix=%{_prefix} --root=%{buildroot}
popd
%endif

%post -n libnotmuch%{libversion} -p /sbin/ldconfig
%postun -n libnotmuch%{libversion} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING COPYING-GPL-3 NEWS README
%{_bindir}/%{name}
%{_bindir}/%{name}-emacs-mua
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man5/%{name}-hooks.5*
%{_mandir}/man7/%{name}-search-terms.7*
%{_mandir}/man7/%{name}-properties.7*

%files -n libnotmuch%{libversion}
%defattr(-,root,root)
%{_libdir}/libnotmuch.so.%{libversion}*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}.h
%{_libdir}/libnotmuch.so

%if %{with python}
%files -n python-%{name}
%defattr(-,root,root)
%doc bindings/python/README
%{python_sitelib}/%{name}/
%{python_sitelib}/%{name}*egg-info

%files -n python-%{name}-doc
%defattr(-,root,root)
%doc bindings/python/docs/build/dirhtml/
%endif

%if %{with python3}
%files -n python3-%{name}
%defattr(-,root,root)
%doc bindings/python/README
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{name}*egg-info
%endif

%if %{with emacs}
%files emacs
%defattr(-,root,root)
%{_datadir}/emacs/site-lisp/
%endif

%changelog
* Sat Mar 10 2018 carmen@carmenbianca.eu
- update to 0.26
  * Add python3-Sphinx to unconditional BuildRequires
  - Support indexing cleartext of encrypted e-mails
  - Python bindings specific Debian packaging is removed
  - cli:
    + Support for re-indexing existing messages
    + Support maildir synced tags in new.tags
    + Support /regex/ in new.ignore
  - Library changes:
    + Indexing files with duplicate message-id
    + New functions to count files
    + New function to remove properties
    + Change return value of notmuch_thread_get_authors from NULL to empty string
    + Transition notmuch_database_add_message to notmuch_database_index_file
* Thu Oct 19 2017 mimi.vx@gmail.com
- update to 0.25.1
  - disable handling x-display in text/enriched messages
* Thu Sep 14 2017 zaitor@opensuse.org
- Add conditional for pkgconfig(gmime-2.6) and new
  pkgconfig(gmime-3.0) BuildRequires: adjust to whats available in
  Tumbleweed and what the source supports.
* Tue Sep  5 2017 abhishek.lekshmanan@suse.com
- version 0.25
  * use sha256 files for checksum & gpg signatures
  * Add notmuch-emacs-mua binary
  - Add regexp searching for mid, paths, and tags.
  - Skip HTML tags when indexing
  - cli:
    + Bash completion is now installed to /usr/share by default.
    + Allow space as separator for keyword arguments.
  - emacs:
    + Support for stashing message timestamp in show and tree views
    + Don't use 'function' as variable name
  - Library changes:
    + Add workaround for date parsing of bad input in older GMime
    + Replace deprecated functions with status returning versions
    + Add support for building against GMime 3.0.
    + Rename libutil.a to libnotmuch_util.a.
    + libnotmuch SONAME is incremented to libnotmuch.so.5.
- version 0.24.2
  - Fix output from `notmuch dump --include=properties` to not include tags.
  - emacs: Fix filename stashing in tree view.
- version 0.24.1
  - Fix regressions in non-regexp search for `from:` and `subject:`
  - Fix several memory leaks in `notmuch show`
  - Fix bug in dump header
  - Fix a read-after-free in the library.
- version 0.24
  - Regular expression searches supported for `from:` and `subject:`
  - Run external `notmuch-` prefixed commands as subcommands
  - New default output format to 3
  - emacs:
    + Postpone and resume messages in `notmuch-message-mode` (composition)
    + Address Completion improvements
    + A configurable Tag jump menu
    + Single command to refresh all buffers with `M-=`
    + Stop display of `application/*` parts
    + Small change in the api for notmuch-search-tag
    + Bugfix for sending messages with very long headers
    + `notmuch emacs-mua` command installed with the Emacs interface
    + Notmuch Emacs desktop integration
  - Library changes:
    + `notmuch_query_count_messages` is now non-destructive
    + Improved handling of DatabaseModifiedError
- version 0.23.6
  - fix read-after-free bug in `notmuch new`
* Thu Feb 23 2017 mvetter@suse.com
- Update to version 0.23.5:
  * Fix quoting bug in configure. This had introduced a RUNPATH into the
    notmuch binary in cases where it was not not needed.
* Mon Dec 26 2016 hzhr+os@mailbox.org
- version 0.23.4
  - Improve error handling in notmuch insert
  - Restore autoload cookie for notmuch-search
* Sat Dec 10 2016 hzhr+os@mailbox.org
- version 0.23.3
  - Treat disappearing files during notmuch new as non-fatal
  - Fix incompatibility (related to signature size) with gnupg 2.1.16
- version 0.23.2
  - Fix notmuch-interesting-buffer and notmuch-cycle-notmuch-buffers
  - Restore compatibility with Emacs 23
- version 0.23.1
  - Require Xapian >= 1.2.6
  - Fix default colours for unread and flagged messages
  - Fix test failure with Emacs 25.1
- version 0.23
  - Compiling against Xapian 1.4 enables several new features
  - Support for single argument date: queries
  - Support for blocking opens
  - Support for named queries
  - Message property API
  - Bug fix for `notmuch_directory_set_mtime`
  - Support for compile time options
  - Dump/Restore support for configuration information and properties
  - Make notmuch-message-mode use insert for fcc
  - Make internal address completion customizable
  - Allow internal address completion on an individual basis
  - Resend messages
  - Face customization is easier
  - Add support for `notmuch_database_get_all_tags`
  - Go bindings moved to contrib
  - Add support for `notmuch_threads_t` and `notmuch_thread_t`
  - Fixed constant values so they are not all zero anymore
- version 0.22.2
  - Silence gdb more
  - Hardcode fingerprint in PGP/MIME tests
* Thu Aug 25 2016 mimi.vx@gmail.com
- version 0.22.1
  - Correct the definition of LIBNOTMUCH_CHECK_VERSION.
  - Document the (lack of) operations permitted on a closed database.
  - Fix race condition in dump / restore tests.
  - Notmuch-mutt: Use env to locate perl.
  - Emacs: Tell message-mode mode that outgoing messages are mail
  - Emacs: This makes message-mode configuration behave more predictably.
  - Respect charset of MIME parts when reading them
  - Fix previous assumption that everyone uses UTF-8.
* Sat Jun 18 2016 lmb@suse.com
- version 0.22
  - Xapian 1.3 support
  - Limited support for S/MIME messages
  - Fix for threading bug involving deleting and re-adding messages.
  - Fix for case-sensitive content disposition headers.
  - Fix handling of 1 character directory names at top level.
  - Emacs: Notmuch replies now include all parts shown in the show view
  - Emacs: Filtering or Limiting messages is now bound to `l` in the
    search view
  - Emacs: `F` forwards all open messages in a thread
  - Emacs: Preferred content type can be determined from the message
    content
- version 0.21
  - Notmuch now requires gmime >= 2.6.7. The gmime 2.4 series is no
    longer supported.
  - Database revision tracking: `lastmod:` queries
  - Date queries now support `date:<expr>..!` shorthand for
    `date:<expr>..<expr>`
  - Notmuch database upgrade to support `lastmod:` queries
  - The `notmuch address` command supports new deduplication schemes
* Wed Jul  8 2015 dsterba@suse.cz
- version 0.20.2
  - Emacs: Bug fix for marking messages read in notmuch-tree mode
- version 0.20.1
  - test suite fixes
- version 0.20
  - There is a new mimetype: search prefix
  - Path to gpg is now configurable
  - Notmuch-Mutt: Support messages without Message-IDs.
  - Undeprecate single message mboxes
  - Contrib: notmuch-deliver is removed
  - Improved notmuch-search-terms.7
* Wed Feb  4 2015 mvyskocil@opensuse.org
- workaround a source checker issue by moving bcond macros behind
  Name and Version tag
* Thu Jan 29 2015 dsterba@suse.cz
- readd the signature file and update keyring
* Thu Jan 29 2015 dsterba@suse.cz
- spec updates
  - remove gpg checks (broken) and the related files
  - define lib version
- version 0.19
  - Stopped notmuch dump failing if someone writes to the database
  - notmuch insert requires succesful message indexing for success status
  - notmuch insert has gained support for post-insert hook
  - notmuch deliver is deprecated
  - notmuch search now supports --duplicate=N option with --output=messages
  - Added notmuch address subcommand
- versions 0.18.1, 0.18.2
  - This is a bug fix and portability release
  - Resurrect support for single-message mbox files
- version 0.18
  - The folder: search prefix now requires an exact match
  - There is a new path: search prefix
  - Notmuch database upgrade due to folder: and path: changes
  - Support for indexing mbox files has been dropped
  - notmuch dump now defaults to batch-tag format
  - notmuch new has a --quiet option
  - notmuch insert respects maildir.synchronize_flags config option
- version 0.17
  - Incompatible change in SHA1 computation
  - New options to better support handling duplicate messages
  - Improved notmuch new performance for unchanged folders
  - notmuch reply --format=text RFC 2047-encodes headers
  - notmuch compact command
  - emacs interface:
  - notmuch-tree (formerly notmuch-pick) has been added to mainline
  - The notmuch-tag function now requires a list of tag changes
  - Fixed notmuch-reply putting reply in primary selection
  - Fixed notmuch-mua-reply point placement when signature involved
- version 0.16
  - Support for delivering messages to Maildir
  - notmuch count --batch option
  - notmuch tag option to remove all tags from matching messages
  - Decrypting commands explicitly expect a gpg-agent
  - Bash command-line completion
  - many emacs interface updates
* Mon Feb 18 2013 mvyskocil@suse.com
- remove zsh completion, it's part of zsh itself
* Mon Feb 18 2013 mvyskocil@suse.com
- drop contrib from installed files
- install zsh to correct location
- instal notmuch.el as notmuch-emacs package like Debian do
* Mon Feb 18 2013 mvyskocil@suse.com
- initial packaging of notmuch 0.15.2 for SUSE
  * including python/python3 bindings
  * and notmuchmail (the original emacs lisp based
    email client for notmuch library)
